

; This file consists of four parts.  The first is optional [ alias ]
; The second defines the processes, another defines sets and the last
; indicates the set that will be started by DEFAULT.

; The first section consists of alias=name statements.  Alias substitution occurs
; early so anything can be aliased.
;
; The second section consists of a list of processes with dependencies and
; behavior.  Most have been replaced by macros to suppress some of the complexity.
; The macros used by this script are stored in the pdm_startup.tpl.i file.  A
; process specification consists of the following:

; [ process-tag ] - an identifier for the process, properties, flags and
; dependencies.  You may append ":UNIX_ONLY" or "NT_ONLY" if the process
; only applies to a single platform.  You must use the same tag when adding
; it to a process set.
;
; Properties:
;     command= -    full path to the executable. I may also have commandline args.
;                   This is expanded by the daemon so that $expansion will
;                   pickup the stuff from the remote host.
;     nx_namespace= Environment name space.

;     slump_name= - optional name used to track slump connected status
;                   It is required if we have a process dependent of
;                   this process connecting to slump.
;                   The daemon proctor slump_name must be "agent_%h"
;                   "%h" will be replaced with the host name.
;                   For this reason the host property should be the first
;                   property specified.
;                   !p in the slump name will be replaced with the
;                   pid of the daemon.

;     display= -    optional, name for pdm_status (process-tag used otherwise)
;     return_code=  optional, This code will be checked against the
;                   exit code.  Only an ERROR will be reported at this time if
;                   there is a difference.

;     host= host name.  This is case sensitive.  It is used to select
;                       the appropriate daemon proctor and host to run the daemon.
;                       If the process is to be started on the local host
;                       then $NX_LOCAL_HOST may be used.
;     directory - This property must specify the default directory for the
;                 process.  If this is an daemon proctor then it must specify the NX_ROOT.
;                 Typically it can be left as $NX_ROOT
;                 Not used on UNIX.
;    classpath  - This sets the CLASSPATH variable for the daemon.
;                 DO NOT use NT style drive letters (c:).  Use $expand
;                 environment variables for the base directory.

; Flags:
;     transitory - if present, the process is not a daemon.
;     restart [ scope ] -  possibilities are "restart",
;                          "restart dependents",
;                          "restart all"
;     shutdown [ scope ] - possibilities are "shutdown",
;                          "shutdown dependents",
;                          "shutdown all"
;     redirect_stdio -   This sets the NX_REDIRECT_STDIO variable for the
;                daemon.  After the daemon connects to slump.  It will
;                start piping its own STDIO to the log file.
;                WARNING: If you do not wait on slump the pipe can fill
;                up and your daemon will freeze.
;     proctor -   This identifies the process as a daemon proctor.
;               A daemon proctor must set this flag.
;               The daemon proctor must be defined before the process using it.
;               The slump name must be proctor_%h
;
;     required  At least one of your daemons should be flagged as required.
;               This will indicate to the daemon manager when it can allow
;               processes dependent on the daemons to start to continue.  If
;               no daemons in the set are flagged as required then the daemon
;               manager will try very hard to start all daemons in the set.
;               Daemons pre-requisite to a required daemon will automatically
;               be required.
;
;               IMPORTANT: The daemon manager will continue to try to start
;                          all daemons in the set after the required daemons
;                          have started until the daemon manager times out.
;
;     NOTE:  restart and shutdown describe behavior when a daemon dies.
; Dependencies:
;       after proc-tag event [ + time ]
;       Valid events are "starts", "finishes", "connects" "init_comp".
;       If present, + time is an aditional time to wait for the daemon(s)
;       to stabilize before starting the next one.
;
;       NOTE: init_comp is only valid for daemons dependent on a domsrvr.
;             ie. after domsrvr init_comp + 3
;
;  Limited quoted strings are allowed in the commandline.  Single quote
;  your string inside the double quotes.
;
; MACROS are used to simplify the process specification definitions.  They are stored
; in the pdm_startup.i file.  A macro is limited to defining processes.  The format is
; as follows:

; #define MACRO_NAME ( [arg_list] )
; statements

; The arglist is a list of zero or more arguments separated by commas.
; The first statement must be the process tag. " [ PROCESS_TAG ].
; It is followed by zero or more statements.  Defining dependencies are note allowed
; here.  Define dependencies after the process specification is instantiated.
; Macros are instantiated as follows:
;
; macro_name ([arg_list])
; [after proc connects + 3]
;
; The macro_name is case-sensitive.  The dependency is optional.
;
; RESERVED WORDS: Reserved words are case insensitive.
;                 after,agent,all,alias,command,complete_timeout,connects,default,directory,
;                 display, finishes, host, procset, proctor, required, restart, shutdown,
;                 slump_name, starts, transitory
;
; CAUTION:  Reserved words can not be used as marco names or arguments to macros.  Note that
;           our resered words are NOT case sensitive.
;
; PROCESS SETS         Process sets are defined after the processes are defined.
;                      You may define sets and then define another set that includes
;                      a previously defined set.  They are defines as follows.
;  [ proc_set_name ]
;  processes
;
;  proc_set_name       This is a unique name in the name space.
;  processes           This is one or more process names defined earlier and
;                      commonly defined one per line.
;
; If you are on an NT box the daemon proctor installs as an automatic service.
; You will have to start it after installation.

; The following NT commands are usually done by the install and deinstall
; procedure.
; Install the remote daemon proctor with pdm_proctor_nxd -i
; De-install the remote daemon proctor with pdm_proctor_nxd -u
;
; The proctor on a UNIX box is started with pdm_proctor_init
;

#include "$NX_ROOT/pdmconf/pdm_startup.i"

[ alias ]
database=DB_PROV_REPLACE
LDAP_HOST=$NX_LOCAL_HOST


;COMPUTER GENERATED REMOTE HOST ALIASES START
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Please do not edit between this banner comment and the next.


_REMOTE_HOST1="QMNAMS1129"
_REMOTE_HOST2="qmnams1129"


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;COMPUTER GENERATED REMOTE HOST ALIASES END

_PROCTOR(proctor1,$NX_LOCAL_HOST)

MSGCAT_BUILD(msgcat_build,$NX_LOCAL_HOST)
after sw_ver_ctl connects + 3

DDICTBUILD(ddictbuild,$NX_LOCAL_HOST)
after sw_ver_ctl connects + 3

PDM_INFO(pdm_info,$NX_LOCAL_HOST)
after sw_ver_ctl connects + 3

GATHER_PSLIST(gather_pslist,$NX_LOCAL_HOST)
after domsrvr connects + 5 
GATHER_LOGS_PRI(gather_logs_pri,$NX_LOCAL_HOST)
after domsrvr connects + 10 

PDM_LOGFILE()

CONFIRM_DB()
after ddictbuild finishes

DDICT_RD(ddict_rd:UNIX_ONLY,$NX_LOCAL_HOST)
after ddictbuild finishes

; SQL is only supported for NT servers
DB_PROVIDER(sql_prov_nxd, "$NX_ROOT/bin/sql_prov_nxd _prov $NX_DB_STUFF", "SQL Server(sql_prov_nxd)")
after ddictbuild finishes


DB_PROVIDER(ing_prov_nxd, "$NX_ROOT/bin/ing_prov_nxd _prov $NX_DB_STUFF", "Ingres Interface(ing_prov_nxd)")
after ddictbuild finishes


DB_PROVIDER(orcl_prov_nxd, "$NX_ROOT/bin/orcl_prov_nxd _prov $NX_DB_STUFF", "Oracle DB (orcl_prov_nxd)")
after ddictbuild finishes


SW_VER_CTL()

NX_USER()
after database connects + 3

LICENSE_NXD()

EHM()
after database connects + 3

EHC()
after ehm connects + 3

TNGFILTER()
after ehc connects

TNGWRITER()
after ehc connects

PCRPT()

PDM_EXPORT_MGR()

SPELLCHECK()

SPELSRVR(spel_srvr, $NX_LOCAL_HOST, spelsrvr, "rpc_srvr:%h")
SPELSRVR(spel_srvr2, $NX_LOCAL_HOST, spelsrvr:local2, "rpc_srvr:%h")
BPVIRTDB_SRVR()
after database connects + 3
after license_nxd connects

LDAP_VIRTDB(LDAP_HOST)
after database connects + 3
after bpvirtdb_srvr connects + 3
after license_nxd connects

; domsrvr options
;   -D DISPLAY NAME
;   -l logon name. Manditory for remote domsrvrs.
;   -s spel_srvr logon name.  Used to select a specific or local spel srvr.

;  #################################################################
;  ####                                                        #####
;  #### DO NOT EDIT THIS DOMSRVR unless you are adding a remote#####
;  #### domsrvr.                                               #####
;  #### One default domsrvr is required for backwards          #####
;  #### compatibility.                                         #####
;  ####                                                        #####
;  #################################################################

DOMSRVR(domsrvr,$NX_LOCAL_HOST,domsrvr,spelsrvr,"","")
after bpvirtdb_srvr connects + 3
after ldap_virtdb connects + 3
required

#ifdef NX_SA_PRIMARY_DOMSRVR
DOMSRVR(sa_domsrvr,$NX_LOCAL_HOST,"domsrvr:sa",spelsrvr,"","")
display = "SA Object Mgr  (domsrvr:sa)"
after bpvirtdb_srvr connects + 3
after ldap_virtdb connects + 3
required
#endif

; Define the WSP domsrvr if the wsp_domsrvr option is installed

#ifdef NX_WSP_DOMSRVR
DOMSRVR(wsp_domsrvr,$NX_LOCAL_HOST,"$NX_WSP_DOMSRVR",spelsrvr,"WSP_Domsrvr","$NX_WSP_WEBENGINE")
display = "WSP Object Mgr  ($NX_WSP_DOMSRVR)"
after bpvirtdb_srvr connects + 3
after ldap_virtdb connects + 3
required
#endif

;COMPUTER GENERATED LOCAL SERVERS START
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Please do not edit between this banner comment and the next.



WEBENGINE (_web_eng1, $NX_LOCAL_HOST, "web:local", "domsrvr", $NX_ROOT/bopcfg/www/web.cfg, "", "rpc_srvr:%h")

REP_DAEMON (_rep_daemon_local, $NX_LOCAL_HOST, "rep_daemon:%h")
after domsrvr connects



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;COMPUTER GENERATED LOCAL SERVERS END

; since the animator depends on the domsrvr and there are
; three flavors of domsrvrs we must have three animator flavors
; one dependent on each.
; Only one may be started.

ANIMATOR_NXD(animator_nxd)
after domsrvr connects

PDM_REST_NXD(pdm_rest_nxd, $NX_LOCAL_HOST)
after domsrvr connects


#ifdef NX_TTV_ENABLED
TTV_NXD(ttv_nxd, domsrvr)
after domsrvr connects
#endif

RPC_SRVR(rpc_srvr, $NX_LOCAL_HOST, "rpc_srvr:%h")

DBMONITOR_NXD(dbmonitor_nxd)
after domsrvr connects

MDB_REGISTRATION_NXD(mdb_registration_nxd)

;KPI daemons
KPI_DAEMON(kpi_daemon, $NX_LOCAL_HOST, "kpi_daemon:%h", domsrvr)
after domsrvr connects

;ODBC server
ODBC_SERVER(oaserver, $NX_LOCAL_HOST)

; KT daemons
KT_DAEMON(kt_daemon, $NX_LOCAL_HOST )
after domsrvr connects

BU_DAEMON(bu_daemon, $NX_LOCAL_HOST )
after domsrvr connects

REP_DAEMON("rep_daemon", $NX_LOCAL_HOST, "rep_daemon:%h")
after domsrvr connects

KRC_DAEMON( "krc_daemon", $NX_LOCAL_HOST)
after domsrvr connects

;keit_daemon must start only after the kt daemon is started
KEIT_DAEMON( "keit_daemon", $NX_LOCAL_HOST)
after kt_daemon connects + 5

EBR_DAEMON(bpebr_nxd, $NX_LOCAL_HOST )
after keit_daemon connects + 5

EID_DAEMON(bpeid_nxd, $NX_LOCAL_HOST )
after bpebr_nxd connects + 5

; QUERYSERVER()

BPNOTIFY_NXD()
after domsrvr connects
BOP_LOGIN( bop_login, $NX_LOCAL_HOST )

PDM_TEXT_NXD()
after domsrvr connects

PDM_MAIL_NXD(pdm_mail_nxd, $NX_LOCAL_HOST)

PDM_MAILEATER_NXD(pdm_maileater_nxd, $NX_LOCAL_HOST)
after pdm_text_nxd connects + 3

UNICNV(uniconv:UNIX_ONLY,$NX_LOCAL_HOST,"HOST_IP_REPLACE:uniconv")
after ehc connects

TNGCNV(tngcnv:NT_ONLY,$NX_LOCAL_HOST,"HOST_IP_REPLACE:tngcnv")
after ehc connects

; ServiceDesk tomcat
PDM_TOMCAT_CONTROLLER(pdm_tomcat, $NX_LOCAL_HOST, "pdm_tomcat-%h" )
after domsrvr connects + 5

; Workflow tomcat
#ifdef NX_CAWF_HOSTNAME
CAWF_TOMCAT_CONTROLLER(cawf_tomcat, $NX_CAWF_HOSTNAME, "pdm_tomcat-%h-CAWF")
after domsrvr connects + 5
#endif

; VIZ tomcat
#ifdef NX_VIZ_INSTALLED
VIZ_TOMCAT_CONTROLLER(viz_tomcat, $NX_LOCAL_HOST, "pdm_tomcat-%h-VIZ")
after domsrvr connects + 5
#endif

; SA tomcat
#ifdef NX_SA_SERVER_ON_PRIMARY
SA_TOMCAT_CONTROLLER(sa_tomcat, $NX_LOCAL_HOST, "pdm_tomcat-%h-SA")
after domsrvr connects + 5
#endif

; REST tomcat
#ifdef NX_REST_INSTALLED
REST_TOMCAT_CONTROLLER(rest_tomcat, $NX_LOCAL_HOST, "pdm_tomcat-%h-REST")
after pdm_rest_nxd finishes
#endif

; This is the Primary Web Engine.
WEBENGINE(webengine, $NX_LOCAL_HOST, web:local, domsrvr, $NX_ROOT/bopcfg/www/web.cfg, "", "rpc_srvr:%h")
after sw_ver_ctl connects + 3
restart

; Define the WSP webengine if the wsp_webengine option is installed.
; WSP users connect to web:local if this option is not install.

#ifdef NX_WSP_WEBENGINE
[ wsp_webengine ]
; Do not change the host - the WSP webengine MUST run on the primary server.
host = $NX_LOCAL_HOST
command = "$NX_ROOT/bin/webengine -q -d '$NX_WSP_DOMSRVR' -S $NX_WSP_WEBENGINE -C pdmweb_wsp.exe"
slump_name = $NX_WSP_WEBENGINE
display = "WSP Web Engine      ($NX_WSP_WEBENGINE)"
after sw_ver_ctl connects + 3
restart
#endif


ARCPUR_SRVR(arcpur_srvr,$NX_LOCAL_HOST,arcpur_srvr)
restart
after domsrvr connects

; These processes are examples for how to set the log level using pdm_d_mgr
; This is useful if you expect the box to be rebooted and you want the
; logging to be reset when the daemons are started automatically.
; You will want to tune the pdm_logstat command by selectively turning
; up logging.  Do this by editing the actual command in the pdm_startup.i file.
; To enable just set the NX.env variable NX_PDM_LOGSTAT=verbose
PDM_LOGSTAT(verbose, $NX_LOCAL_HOST)
PDM_LOGSTAT(warning, $NX_LOCAL_HOST)


; There are four flavors of domsrvr
; Only include one of the following four
; domsrvr modes.  Select it by changing the
; NX_DOMSRVR_MODE NX.env variable
; Multi process domsrvr set


; Try to put all daemons that depend on the domsrvr in one of these three
; process sets.  This is so that they will be added or removed with the changing
; of the NX_DOMSRVR_MODE variable.

[ procset MP]
spel_srvr
; spel_srvr2
domsrvr
bpvirtdb_srvr
animator_nxd
pdm_rest_nxd

#ifdef NX_WSP_DOMSRVR
wsp_domsrvr
#endif

; bop_login

pdm_text_nxd
pdm_mail_nxd
pdm_maileater_nxd

; To enable the webengine on the Primary Server uncomment
; the webengine here.
; Make sure the webengine is installed on the Primary Server
; WEBENGINE_DISABLED by pdm_edit.pl

#ifdef NX_WSP_WEBENGINE
wsp_webengine
#endif

arcpur_srvr

;COMPUTER GENERATED LOCAL SERVER PROCESSES START
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Please do not edit between this banner comment and the next.

; These servers were added to the MP process set.

_web_eng1
_rep_daemon_local
bop_login
kt_daemon
keit_daemon
bu_daemon
bpebr_nxd
bpeid_nxd
krc_daemon


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;COMPUTER GENERATED LOCAL SERVER PROCESSES END

[ procset FILTERING ]
tngfilter
tngwriter
ehc
; UNICONV DISABLED by pdm_edit.pl
; TNGCNV_REPLACE

; Resist the temptation to add more daemons to DBADMIN mode.
; We may have to add tomcat to DBADMIN for configure.  Hopefully not.
[ procset DBADMIN ]
pdm_info
ddictbuild
; #ifdef NX_PDMXML_DIRECT_PARSE
msgcat_build
; #endif
pdm_logfile
ddict_rd:UNIX_ONLY
database
mdb_registration_nxd

[ procset PDMBASE ]
sw_ver_ctl
confirm_db
ddict_rd:UNIX_ONLY
ddictbuild
; #ifdef NX_PDMXML_DIRECT_PARSE
msgcat_build
; #endif
pdm_logfile
database
nx_user
license_nxd
pcrpt
ehm
lexagent_nxd

[ procset PDMBOP ]
; bpebr_nxd
; bpeid_nxd
; kt_daemon
; bu_daemon
; rep_daemon Disabled by pdm_edit.pl
; krc_daemon
; keit_daemon
rpc_srvr
dbmonitor_nxd
mdb_registration_nxd
kpi_daemon
pdm_export_mgr


; Set by Options Manager:
$NX_TTV_ENABLED

; mp_domsrvr Multiple Domsrvr Mode
; Set NX_DOMSRVR_MODE=MP

"$NX_DOMSRVR_MODE"


[ procset SDADMIN ]
DBADMIN
spel_srvr
domsrvr
bpvirtdb_srvr


[ procset OFFLINE_REPORTING ]
DBADMIN
sw_ver_ctl
bpnotify_nxd
confirm_db
nx_user
license_nxd
; kt_daemon
rpc_srvr
spel_srvr
domsrvr
bpvirtdb_srvr
; bop_login

; WEBENGINE_DISABLED by pdm_edit.pl


[ procset MAIN_PROCSET]
; queryserver
msgcat_build
pdm_info
sw_ver_ctl
gather_pslist
gather_logs_pri
bpnotify_nxd
PDMBASE
PDMBOP
; FILTERING_REPLACE
"$NX_PDM_LOGSTAT"
pdm_tomcat

#ifdef NX_CAWF_HOSTNAME
cawf_tomcat
#endif

#ifdef NX_VIZ_INSTALLED
viz_tomcat
#endif

#ifdef NX_REST_INSTALLED
rest_tomcat
#endif

#ifdef NX_SA_SERVER_ON_PRIMARY
sa_tomcat
#endif

#ifdef NX_SA_PRIMARY_DOMSRVR
sa_domsrvr
#endif

;COMPUTER GENERATED REMOTE SERVER PROCESSES START
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Please do not edit between this banner comment and the next.


_PROCTOR ( _proctor_QMNAMS1129, "QMNAMS1129")
complete_timeout=5
agent

SECONDARY_VER_CTL ( _ver_ctl_QMNAMS1129, "QMNAMS1129")
after sw_ver_ctl connects

DDICTBUILD ( _ddictbuild_QMNAMS1129, "QMNAMS1129" )
after _ver_ctl_QMNAMS1129 finishes
after _msgcat_build_QMNAMS1129 finishes

MSGCAT_BUILD ( _msgcat_build_QMNAMS1129, "QMNAMS1129" )
after _ver_ctl_QMNAMS1129 finishes

GATHER_PSLIST ( _gather_pslist_QMNAMS1129, "QMNAMS1129" )
after _ddictbuild_QMNAMS1129 finishes + 5
after _msgcat_build_QMNAMS1129 finishes + 5
after _ver_ctl_QMNAMS1129 finishes + 5

GATHER_LOGS_SEC ( _gather_logs_sec_QMNAMS1129, "QMNAMS1129" )
after _ddictbuild_QMNAMS1129 finishes + 10
after _msgcat_build_QMNAMS1129 finishes + 10
after _ver_ctl_QMNAMS1129 finishes + 10

DOMSRVR (_domsrvr_QMNAMS11291,"QMNAMS1129",domsrvr:11,spelsrvr:QMNAMS1129:1,"",".*")
after bpvirtdb_srvr connects + 3
after _ddictbuild_QMNAMS1129 finishes
after _ver_ctl_QMNAMS1129 finishes
after _msgcat_build_QMNAMS1129 finishes
after ldap_virtdb connects + 3

SPELSRVR (_spel_srvr_QMNAMS11291, "QMNAMS1129", spelsrvr:QMNAMS1129:1, "rpc_srvr:%h")
after _ddictbuild_QMNAMS1129 finishes
after _ver_ctl_QMNAMS1129 finishes
after _msgcat_build_QMNAMS1129 finishes

WEBDIRECTOR ( _webdir_QMNAMS11291, "QMNAMS1129",web:dir:QMNAMS1129:1,pdmweb_d1.exe)
RPC_SRVR (_rpc_srvr_QMNAMS1129, "QMNAMS1129", "rpc_srvr:%h")

_PROCTOR ( _proctor_qmnams1129, "qmnams1129")
complete_timeout=5
agent

SECONDARY_VER_CTL ( _ver_ctl_qmnams1129, "qmnams1129")
after sw_ver_ctl connects

DDICTBUILD ( _ddictbuild_qmnams1129, "qmnams1129" )
after _ver_ctl_qmnams1129 finishes
after _msgcat_build_qmnams1129 finishes

MSGCAT_BUILD ( _msgcat_build_qmnams1129, "qmnams1129" )
after _ver_ctl_qmnams1129 finishes

GATHER_PSLIST ( _gather_pslist_qmnams1129, "qmnams1129" )
after _ddictbuild_qmnams1129 finishes + 5
after _msgcat_build_qmnams1129 finishes + 5
after _ver_ctl_qmnams1129 finishes + 5

GATHER_LOGS_SEC ( _gather_logs_sec_qmnams1129, "qmnams1129" )
after _ddictbuild_qmnams1129 finishes + 10
after _msgcat_build_qmnams1129 finishes + 10
after _ver_ctl_qmnams1129 finishes + 10

PDM_TOMCAT_CONTROLLER (_pdm_tomcat_qmnams1129,"qmnams1129", pdm_tomcat-qmnams1129)
after _ver_ctl_qmnams1129 finishes
after _msgcat_build_qmnams1129 finishes

WEBENGINE (_web_eng_qmnams11291, "qmnams1129", web:qmnams1129:1, "any", $NX_ROOT/bopcfg/www/qmnams1129-web1.cfg, "WEBDIR:QMNAMS1129:1", "rpc_srvr:%h")
after _webdir_QMNAMS11291 connects +3
after _ver_ctl_qmnams1129 finishes
after _msgcat_build_qmnams1129 finishes

RPC_SRVR (_rpc_srvr_qmnams1129, "qmnams1129", "rpc_srvr:%h")



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;COMPUTER GENERATED REMOTE SERVER PROCESSES END
;COMPUTER GENERATED REMOTE SERVER PROCSETS START
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Please do not edit between this banner comment and the next.



[ procset _REMOTE_QMNAMS1129 ]
_msgcat_build_QMNAMS1129
_proctor_QMNAMS1129
_ver_ctl_QMNAMS1129
_gather_pslist_QMNAMS1129
_gather_logs_sec_QMNAMS1129
_rpc_srvr_QMNAMS1129
_domsrvr_QMNAMS11291
_spel_srvr_QMNAMS11291

[ procset _REMOTE_qmnams1129 ]
_msgcat_build_qmnams1129
_proctor_qmnams1129
_ver_ctl_qmnams1129
_gather_pslist_qmnams1129
_gather_logs_sec_qmnams1129
_rpc_srvr_qmnams1129
_pdm_tomcat_qmnams1129
_web_eng_qmnams11291

[ procset _REMOTE_PROCSET ]
MAIN_PROCSET
_REMOTE_QMNAMS1129
_REMOTE_qmnams1129


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;COMPUTER GENERATED REMOTE SERVER PROCSETS END

; The default line should be the last line
; This defines the set that will be started by default.

[ default procset _REMOTE_PROCSET ]

